@@ -35,16 +35,6 @@
 #'
 #' }
 #'
-#' @section Devtools checks:
-#'
-#' Devtools currently provides a few extra checks that \code{R CMD check}
-#' does not - these are typically things that the CRAN maintainers will
-#' complain about if you haven't done, but haven't yet included in the formal
-#' testing process. These are run after \code{R CMD check}
-#'
-#' There is currently one test that checks you haven't includes any non-standard
-#' directories in the top-level R file.
-#'
 #' @param pkg package description, can be path or package name.  See
 #'   \code{\link{as.package}} for more information
 #' @param document if \code{TRUE} (the default), will update and check
@@ -90,8 +80,6 @@ check <- function(pkg = ".", document = TRUE, doc_clean = getOption("devtools.cl
   r_cmd_check_path <- check_r_cmd(built_path, cran, check_version,
     force_suggests, args, quiet = quiet, check_dir = check_dir)
 
-  check_devtools(pkg, built_path)
-
   if (cleanup) {
     unlink(r_cmd_check_path, recursive = TRUE)
   } else {
@@ -133,7 +121,7 @@ check_r_cmd <- function(built_path = NULL, cran = TRUE, check_version = FALSE,
     env_vars, ...)
 
   # Return the path to the check output
-  file.path(tempdir(), paste(pkgname, ".Rcheck", sep = ""))
+  file.path(normalizePath(check_dir), paste(pkgname, ".Rcheck", sep = ""))
 }
 
 
@@ -157,7 +145,11 @@ cran_env_vars <- function() {
     "_R_CHECK_DOC_SIZES2_"               = "TRUE",
     "_R_CHECK_CODE_ASSIGN_TO_GLOBALENV_" = "TRUE",
     "_R_CHECK_CODE_ATTACH_"              = "TRUE",
+    "_R_CHECK_CODE_DATA_INTO_GLOBALENV_" = "TRUE",
     "_R_CHECK_DOT_FIRSTLIB_"             = "TRUE",
-    "_R_CHECK_CODE_DATA_INTO_GLOBALENV_" = "TRUE"
+    "_R_CHECK_DEPRECATED_DEFUNCT_"       = "TRUE",
+    "_R_CHECK_REPLACING_IMPORTS_"        = "TRUE",
+    "_R_CHECK_SCREEN_DEVICE_"            = "stop",
+    "_R_CHECK_TOPLEVEL_FILES_"           = "TRUE"
   )
 }
